require "httparty"

module EspnFflApi
  class ApiClient
    attr_reader :league_id, :year
    attr_writer :views, :params

    def initialize(year)
      @year = year
      @league_id = EspnFflApi.config.league_id
    end

    def views
      @views ||= []
    end

    def params
      @params ||= []
    end

    def get
      uri = build_uri(views: views, params: params)
      puts "HTTP GET: #{uri}"
      HTTParty.get(uri)
    end

    private

    def base_uri
      EspnFflApi.config.base_uri + year.to_s + "/segments/0/leagues/" + league_id
    end

    def build_uri(views: [], params: [])
      views_string = views.map do |view|
        next unless ApiClient.api_views.keys.include?(view)
        "view=#{ApiClient.api_views[view]}"
      end.join("&")

      params_string = params.join("&")

      views_string = "?" + views_string unless views_string.empty?

      params_string = "&" + params_string unless params_string.empty?

      base_uri + views_string + params_string
    end

    def self.api_views
      {
        draft: "mDraftDetail",
        live_scoring: "mLiveScoring",
        matchup_score: "mMatchupScore",
        matchup: "mMatchup",
        pending_transactions: "mPendingTransactions",
        positional_ratings: "mPositionalRatings",
        team: "mTeam",
      }
    end
  end
end
